/**
 * 企业信息
 * 汇总
 * 
 *
 * */
 

import { ApplyForUpdateConfig, GardenNoticeUpdateConfig, PolicyUpdateConfig, RegisterUpdateConfig, SettleInForUpdateConfig } from "../config/eccParam/enterprise";
import { OPERATIONALDATATYPE, TABLEID, TABLENAME } from "../config/enum/dbEnum";
import * as enumConfig from "../config/enum/enum";
import { operationalData, selectData, selectManyTableData } from "../data/operationalData";
import { BizError } from "../util/bizError";
import { eccFormParam } from "../util/verificationParam";
import { ERRORENUM } from "../config/enum/errorEnum";
import { getMySqlMs, getToken, md5PwdStr, randomCode, randomId } from "../tools/system";
import moment = require("moment");
import { changeAdd, extractData } from "../util/piecemeal";
import { EnterpriseApplyForConfig } from "../config/splitResult/enterprise";
import { changeEnumValue } from "../util/verificationEnum";
import { start } from "repl";

export async function allEntepriseNameList() {
    let listList = await selectData(OPERATIONALDATATYPE.查询多个, TABLENAME.企业基础信息表, {state:1}, ["enterpriseName", "eId"]);

    let dataList = [];
    listList.forEach(info => {
        dataList.push({
            key:info.enterpriseName,
            value:info.eId
        })
    });

    return {dataList}
}



//==登录登出

export async function adminLogin(loginId:string, pwd:string) {
    let filesList = ["name", "aId", "pwd"];
    let adminUserInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.管理后台用户, {loginId}, filesList);

    if (!adminUserInfo || !adminUserInfo.aId) {
        throw new BizError(ERRORENUM.账号或密码错误);
    }
    if (adminUserInfo.pwd != pwd) {
        throw new BizError(ERRORENUM.账号或密码错误);
    }

    let updateUserInfo = {
        token : getToken(adminUserInfo.uId),
        tokenMs : getMySqlMs()
    };
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.管理后台用户, updateUserInfo, {aId:adminUserInfo.aId});
    

    let userInfo = {
        userId:adminUserInfo.aId,
        userName:adminUserInfo.name,
        token:updateUserInfo.token,
    };

    return {dataInfo:userInfo};
}

export async function adminLogout(uId) {
    let filesList = ["name", "aId", "pwd"];
    let adminUserInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.管理后台用户, {uId}, filesList);
    let updateInfo = {
        token : getToken(adminUserInfo.aId),
        tokenMs : getMySqlMs()
    };
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.管理后台用户, updateInfo, {uId:adminUserInfo.aId});


    return {isSuccess:true};
}


export async function enterpriseLogin(uscc:string, code:string) {
    let filesList = ["eId", "uscc", "enterpriseName", "randomCode"];
    let enterpriseUserInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {uscc}, filesList);

    if (!enterpriseUserInfo || !enterpriseUserInfo.eId || !enterpriseUserInfo.randomCode) {
        throw new BizError(ERRORENUM.请先申请入孵);
    }
    if (enterpriseUserInfo.randomCode != code) {
        throw new BizError(ERRORENUM.验证码错误);
    }
    
    let userInfo = {
        userId:enterpriseUserInfo.eId,
        token:md5PwdStr(enterpriseUserInfo.randomCode),
        userName:enterpriseUserInfo.enterpriseName
    };
  
    return {
        dataInfo:userInfo
    };
}

export async function enterpriseLogout(eId:string) {
    return {isSuccess:true};
}



//企业申请上传资料
export async function enterpriseApplyFor(eId:string) {
    let filesList = ["eId", "uscc", "enterpriseName", "logonAddress", "logonTime"];
    let enterpriseUserInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);
    if (!enterpriseUserInfo || !enterpriseUserInfo.eId) {
        throw new BizError(ERRORENUM.请先申请入孵);
    }
    let leaseFilesList = ["leaseId", "startTime", "endTime", "area", "leaseContract", "entryPlan", "businessLicense", "agreement"];
    let leaseInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.租赁信息, {eId}, leaseFilesList);
    enterpriseUserInfo.logonAddress = JSON.parse(enterpriseUserInfo.logonAddress);
    let dataInfo:any = extractData(EnterpriseApplyForConfig, enterpriseUserInfo);

    dataInfo.logonTime = moment(enterpriseUserInfo.logonTime).format("YYYY-MM-DD");
    dataInfo.leaseTime = `${moment(leaseInfo.startTime).format("YYYY-MM-DD")}至${moment(leaseInfo.endTime).format("YYYY-MM-DD")}`;
    dataInfo.area = leaseInfo.area;

    dataInfo.leaseContract = leaseInfo.leaseContract;
    dataInfo.entryPlan = leaseInfo.entryPlan;
    dataInfo.businessLicense = leaseInfo.businessLicense;
    dataInfo.agreement = leaseInfo.agreement;

    dataInfo.leaseContractModelUrl = "/yuyi/files/孵化协议模板.docx";
    dataInfo.entryPlanModelUrl = "/yuyi/files/孵化企业入驻计划.xlsx";
    dataInfo.agreementModelUrl = "/yuyi/files/三方协议.docx";


    return {dataInfo};
}

export async function updateEnterpriseApplyFor(eId:string, param) {
    const FuncName = "企业修改入驻信息";
    eccFormParam(FuncName, ApplyForUpdateConfig, param );
    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "state"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);
    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }
    if (resInfo.state == 1) {
        throw new BizError(ERRORENUM.已审核请前往小程序登录)
    } 

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.租赁信息, param, {eId});

    return {isSuccess:true};
}



//=======================================================新入孵企业

export async function settleInEnterpriseList(page:number, entepriseName:string) {

    let selectParam:any = {state:enumConfig.STATE.否, register:enumConfig.STATE.否};
    if (entepriseName) selectParam.enterpriseName = {"%like%":entepriseName};

    let filesList = ["eId", "enterpriseName", "uscc", "logonTime"];

    let manyTableInfo:any = {}
    manyTableInfo[TABLENAME.租赁信息] = {column:["area", "unitPrice", "roomNumber", "rent"], where:{} };
    manyTableInfo[TABLENAME.企业孵化信息] = {column:["state", "startTime", "endTime"], where:{} };
    let resList = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, filesList, manyTableInfo, page );
    let allResList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, ["eId"], manyTableInfo );

    let dataList = [];
    resList.forEach(info => {
        dataList.push({
            eId:info.eId,
            enterpriseName:info.enterpriseName,
            uscc:info.uscc,
            logonTime:moment(info.logonTime).format("YYYY-MM-DD"),
            leaseTime:`${moment(info.enterprise_leases[0].startTime).format("YYYY-MM-DD")}至${moment(info.enterprise_leases[0].endTime).format("YYYY-MM-DD")}`,
            leaseTimeStart:info.enterprise_leases[0].startTime || 0,
            leaseTimeEnd:info.enterprise_leases[0].endTime || 0,
            fuHuaTimeStart:info.enterprise_fuhuas[0].startTime||0,
            fuHuaTimeEnd:info.enterprise_fuhuas[0].endTime||0,
            area:info.enterprise_leases[0].area,
            unitPrice:info.enterprise_leases[0].unitPrice,
            roomNumber:info.enterprise_leases[0].roomNumber,
            rent:info.enterprise_leases[0].rent
        });
    });

    return {dataList, dataCount:allResList.length};
}

export async function settleInEnterprisePass(eId:string) {
    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "state"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);

    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }
    if (resInfo.state) throw new BizError(ERRORENUM.该企业已通过审核);


    
    let updateInfo = {
        register:enumConfig.STATE.是,
        randomCode:randomCode()
    }
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业基础信息表, updateInfo, {eId});

    return {isSuccess:true};
}

export async function settleInEnterpriseUpdate(eId:string, param) {
    const FuncName = "修改入驻信息";
    eccFormParam(FuncName, SettleInForUpdateConfig, param );
    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "state"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);
    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }
    if (resInfo.state) throw new BizError(ERRORENUM.该企业已通过审核);

    let updateInfo = {
        enterpriseName:param.enterpriseName,
        uscc:param.uscc,
        logonTime:param.logonTime
    };
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业基础信息表, updateInfo, {eId});
    
    let fuHuaInfo = {
        startTime:param.fuHuaTimeStart,
        endTime:param.fuHuaTimeEndTime,
        state:enumConfig.FUHUASTATE.实体孵化
    };
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业孵化信息, fuHuaInfo, {eId});

    let leaseInfo = {
        area:param.area,
        unitPrice:param.unitPrice,
        roomNumber:param.roomNumber,
        rent:param.rent,
    }
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.租赁信息, leaseInfo, {eId});
    
    return {isSuccess:true};
}


export async function settleInEnterpriseOut(eId:string) {
    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "state"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);

    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }
    if (resInfo.state) throw new BizError(ERRORENUM.该企业已通过审核);

    await operationalData(OPERATIONALDATATYPE.删除, TABLENAME.企业孵化信息, {}, {eId});
    await operationalData(OPERATIONALDATATYPE.删除, TABLENAME.租赁信息, {}, {eId});
    await operationalData(OPERATIONALDATATYPE.删除, TABLENAME.企业基础信息表, {}, {eId});

    return {isSuccess:true};
}

//=================================================活动通知

export async function gardenNoticeList(keywords:string, page:number) {
    let selectParam:any = {};
    if (keywords) selectParam.content = {"%like%":keywords};
    let filesList = ["gnId", "title", "isPublished", "publishTime", "content"];
    let resList = await selectData(OPERATIONALDATATYPE.分页查询, TABLENAME.园区通知表, {}, filesList, page);

    let dataList = [];
    resList.forEach(info => {
        
        dataList.push({
            gnId:info.gnId,
            title:info.title,
            content:info.content,
            isPublished:info.isPublished,
            publishTime:moment(info.publishTime).format("YYYY-MM-DD")
        });
    });

    return {dataList};
}


export async function gardenNoticeInfo(gnId:string) {
    let filesList = ["gnId", "title", "isPublished", "content", "publishTime", "relatedEnterprise"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.园区通知表, {gnId}, filesList);

    let dataInfo = {
        gnId:resInfo.gnId,//id
        title:resInfo.title,//标题
        content:resInfo.content,//内容
        isPublished:resInfo.isPublished,//是否发布（1：是，0：否）
        publishTime:resInfo.publishTime,//发布时间
        relatedEnterprise:JSON.parse(resInfo.relatedEnterprise || '[]'),//关联企业
    };
    return {dataInfo}
}


export async function gardenNoticeUpdate(gnId:string, param) {
    const FuncName = "修改园区通知"
    eccFormParam(FuncName, GardenNoticeUpdateConfig, param );
    let filesList = ["gnId", "title", "isPublished", "content", "publishTime", "relatedEnterprise"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.园区通知表, {gnId}, filesList);

    if (!resInfo.gnId) throw new BizError(ERRORENUM.数据不存在);

    param.publishTime = getMySqlMs(param.publishTime);
    param.relatedEnterprise = JSON.stringify(param.relatedEnterprise);
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.园区通知表, param, {gnId});

    return {isSuccess:true};
}

export async function gardenNoticeAdd(param) {
    const FuncName = "新增园区通知"
    eccFormParam(FuncName, GardenNoticeUpdateConfig, param );

    param.gnId = randomId(TABLEID.园区通知表);
    param.publishTime = getMySqlMs(param.publishTime);
    param.relatedEnterprise = JSON.stringify(param.relatedEnterprise);
    await operationalData(OPERATIONALDATATYPE.增加, TABLENAME.园区通知表, param, {});

    return {isSuccess:true};
}


export async function gardenNoticeDelete(gnId:string) {
    let filesList = ["gnId", "title"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.园区通知表, {gnId}, filesList)
    if (!resInfo || !resInfo.gnId) throw new BizError(ERRORENUM.当前数据不存在); 

    await operationalData(OPERATIONALDATATYPE.删除, TABLENAME.园区通知表, {}, {gnId});
    
    return {isSuccess:true};
}



export async function enterpriseExamineList(year:number, entepriseName:string, page:number) {
    let filesList = [ "mId", "annual",  "BI", "TXP", "RD", "state"];
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column:["enterpriseName"], where:{} };
    if (entepriseName) {
        manyTableInfo[TABLENAME.企业基础信息表].where["enterpriseName"] = {"%like%":entepriseName}
    }
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业经营信息, {annual:getMySqlMs(year)}, filesList, manyTableInfo, page);
    let dataCount = await selectData(OPERATIONALDATATYPE.查询数据量, TABLENAME.企业经营信息, {annual:getMySqlMs(year)}, null);

    let dataList = [];
    resInfo.forEach(info => {
        let dataInfo = {
            enterpriseName:info.enterprise.enterpriseName,
            mId:info.mId,
            annual:moment(info.annual).format("YYYY"),
            BI:info.BI,
            TXP:info.TXP,
            RD:info.RD,
            state:info.state
        };
        dataList.push(dataInfo);
    })
    

    return {dataList, dataCount};
}



export async function enterpriseExamineInfo(mId:string) {
    let filesList = [ "mId", "annual",  "BI", "TXP", "RD"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业经营信息, {mId}, filesList);
    if (!resInfo || !resInfo.mId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    let dataInfo = {
        mId:resInfo.mId,
        BI:resInfo.BI,
        TXP:resInfo.TXP,
        RD:resInfo.RD
    }

    return {dataInfo};
}

export async function enterpriseExamineUpdate( mId, param) {
    let filesList = [ "eId", "annual",  "BI", "TXP", "RD"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业经营信息, {mId}, filesList);
    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    let dataInfo = {
        BI:param.BI,
        TXP:param.TXP,
        RD:param.RD
    }

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业经营信息, dataInfo, {mId});

    return {dataInfo};
}

export async function enterpriseExaminePass(mId) {
    let filesList = [ "eId", "annual",  "BI", "TXP", "RD"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业经营信息, {mId}, filesList);
    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    let dataInfo = {
        state:enumConfig.STATE.是
    }

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业经营信息, dataInfo, {mId});

    return {dataInfo};
}


export async function enterpriseList(entepriseName:string, page:number) {
    let selectParam:any = {};
    if (entepriseName) {
        selectParam.enterpriseName = {"%like%":entepriseName}
    }
    let filesList = ["enterpriseName", "uscc", "logonTime", "logonAddress", "qiYeGuiMo"];
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.租赁信息] = {column:["area", "startTime", "endTime", "roomNumber"], where:{} }; 

    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, filesList, manyTableInfo, page);

    let dataCount = await selectData(OPERATIONALDATATYPE.查询数据量, TABLENAME.企业基础信息表, selectParam, null);

    let dataList = [];
    resInfo.forEach(info => {
        let {enterpriseName, uscc, logonTime, logonAddress, qiYeGuiMo, enterprise_leases} = info;
        let leasesTime = '-'
        if (enterprise_leases[0].startTime){
            leasesTime = `${moment(enterprise_leases[0].startTime).format("YYYY-MM-DD")}至${moment(enterprise_leases[0].endTime).format("YYYY-MM-DD")}`;
        }

        let dataInfo = {
            enterpriseName, //企业名称
            uscc, //统一信用代码
            logonTime:moment(logonTime).format("YYYY-MM-DD"), //注册日期
            logonAddress:changeAdd(JSON.parse(logonAddress)), //注册地址
            qiYeGuiMo,//企业规模
            leasesTime,//孵化时间
            area:enterprise_leases[0].area+"㎡",//租赁面积
            roomNumber:enterprise_leases[0].roomNumber,//室号
        };
        dataList.push(dataInfo);
    })
    

    return {dataList, dataCount};
}


export async function enterpriseManageList(entepriseName:string, year:number, page:number, state:number) {
    let selectParam:any = {state:enumConfig.STATE.是};
    if (entepriseName) {
        selectParam.enterpriseName = {"%like%":entepriseName}
    }

    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业经营信息] = {column:["BI", "TXP", "RD", "annual"], where:{} }; 
    if (year) {
        manyTableInfo[TABLENAME.企业经营信息].where["annual"] = getMySqlMs(year);
    }
    if (state) {
        if (state == 1) manyTableInfo[TABLENAME.企业经营信息].where["state"] = 1;
        else manyTableInfo[TABLENAME.企业经营信息].where["state"] = 0;
    }
    let filesList = ["enterpriseName", "uscc"];
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, filesList, manyTableInfo, page);
    let dataCountList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, ["eId"], manyTableInfo);
    let dataCount = dataCountList.length;
    let dataList = [];
    resInfo.forEach(info => {
        let {enterpriseName, uscc, enterprise_manages} = info;
        let dataInfo = {
            enterpriseName, //企业名称
            uscc, //统一信用代码
            BI:enterprise_manages[0].BI, //营收（万元）
            TXP:enterprise_manages[0].TXP, //纳税（万元）
            RD:enterprise_manages[0].RD,//研发投入（万元）
            annual:moment(enterprise_manages[0].annual).format("YYYY"),//年度
            state:state ? "已审核" : "未审核"
        };
        dataList.push(dataInfo);
    });

    return {dataList, dataCount};
}




export async function enterpriseFinancingList(entepriseName:string,page:number) {
    let selectParam:any = {state:enumConfig.STATE.是};
    if (entepriseName) {
        selectParam.entepriseName = {"%like%":entepriseName}
    }

    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业融资] = {column:["financingAmount", "financingRounds", "investmentDate", "investmentInstitutionsName" ], where:{} };
    let filesList = ["enterpriseName", "uscc"];
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, filesList, manyTableInfo, page);
    let dataCountList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, ["eId"], manyTableInfo);
    let dataCount = dataCountList.length;

    let dataList = [];
    resInfo.forEach(info => {
        let {enterpriseName, uscc, enterprise_financings} = info;
        let dataInfo = {
            enterpriseName, //企业名称
            uscc, //统一信用代码
            financingAmount:enterprise_financings[0].financingAmount, //融资金额（万元）
            financingRounds:changeEnumValue(enumConfig.FINANCINGROUNDS, enterprise_financings[0].financingRounds), //融资轮次
            investmentDate:moment(enterprise_financings[0].investmentDate).format("YYYY-MM-DD"),//获得投资时间
            investmentInstitutionsName:enterprise_financings[0].investmentInstitutionsName,//投资机构名称
        };
        dataList.push(dataInfo);
    });

    return {dataList, dataCount};
}


export async function enterpriseTalentList(name:string, page:number) {
    let selectParam:any = {};
    if (name) {
        selectParam.name = {"%like%":name};
    }

    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column:["enterpriseName" ], where:{} };
    let filesList = ["name", "sex", "birth", "degree", "graduationSchool"];
    let resInfo = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.创业团队, selectParam, filesList, manyTableInfo, page);
    let dataCount = await selectData(OPERATIONALDATATYPE.查询数据量, TABLENAME.创业团队, selectParam, null);

    let dataList = [];
    resInfo.forEach(info => {
        let {name, sex, birth, degree, graduationSchool, enterprise} = info;
        let dataInfo = {
            name, //姓名
            sex:changeEnumValue(enumConfig.SEX, sex), //性别
            birth:moment(birth).format("YYYY-MM-DD"), //出生年月
            degree:changeEnumValue(enumConfig.DEGREE, degree), //最高学历
            graduationSchool,//毕业学校
            enterpriseName:enterprise.enterpriseName,//企业名称
        };
        dataList.push(dataInfo);
    });

    return {dataList, dataCount};
}



//========================================政策
export async function enterprisePolicyList(keywords:string, page:number) {
    let selectParam:any = {};
    if (keywords) selectParam.desc = {"%like%":keywords};
    let filesList = ["poId", "title", "source", "createTimeMs", "closeTimeMs", "isPermanent"];
    let resList = await selectData(OPERATIONALDATATYPE.分页查询, TABLENAME.政策表, selectParam, filesList, page);
    let dataCount = await selectData(OPERATIONALDATATYPE.查询数据量, TABLENAME.政策表, selectParam, null);

    let dataList = []; 
    resList.forEach(info => {
        dataList.push({
            poId:info.poId,
            title:info.title,
            source:info.source,
            createTimeMs:info.createTimeMs,
            closeTimeMs:info.closeTimeMs,
            isPermanent:info.isPermanent
        });
    });

    return {dataList, dataCount};
}


export async function enterprisePolicyInfo(poId:string) {
    let filesList = ["poId", "title", "source", "createTimeMs", "closeTimeMs", "isPermanent", "coverImg", "desc"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.政策表, {poId}, filesList);

    let dataInfo = {
        title:resInfo.title,
        source:resInfo.source,
        desc:resInfo.desc,
        coverImg:resInfo.coverImg ?  JSON.parse(resInfo.coverImg) : [],
        closeTimeMs:new Date(resInfo.closeTimeMs).valueOf(),
        isPermanent:resInfo.isPermanent
    };
    

    return {dataInfo};
}



export async function enterprisePolicyUpdate(poId:string, param) {
    const FuncName = "修改政策表"
    eccFormParam(FuncName, PolicyUpdateConfig, param );
    let filesList = ["poId", "title", "desc", "source", "coverImg", "closeTimeMs", "isPermanent"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.政策表, {poId}, filesList);
    if (!resInfo || !resInfo.poId) throw new BizError(ERRORENUM.数据不存在);

    param.closeTimeMs = getMySqlMs(param.closeTimeMs);
    if (!param.coverImg) param.coverImg = '[]';
    else param.coverImg = JSON.stringify(param.coverImg);
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.政策表, param, {poId});

    return {isSuccess:true};
}

export async function enterprisePolicyAdd( param) {
    const FuncName = "添加政策表"
    eccFormParam(FuncName, PolicyUpdateConfig, param );
  
    param.closeTimeMs = getMySqlMs(param.closeTimeMs);
    param.createTimeMs = getMySqlMs();
    if (!param.coverImg) param.coverImg = '[]';
    else param.coverImg = JSON.stringify(param.coverImg);
    param.poId = randomId(TABLEID.政策表);
    await operationalData(OPERATIONALDATATYPE.增加, TABLENAME.政策表, param, {});

    return {isSuccess:true};
}


export async function enterprisePolicyDelete(poId:string) {
    let filesList = ["poId"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.政策表, {poId}, filesList);
    if (!resInfo || !resInfo.poId) throw new BizError(ERRORENUM.数据不存在);

    await operationalData(OPERATIONALDATATYPE.删除, TABLENAME.政策表, {}, {poId});

    return {isSuccess:true};
}

export async function enterpriseService(enterpriseName, followUpStatus, page) {
    let selectParam:any = {};
    if (followUpStatus) {
        selectParam.followUpStatus = followUpStatus;
    }
    let filesList = ["esId", "needCategory", "applyTime", "followUpStatus", "resolveTime", "needContent"];
    let manyTableInfo:any = {};
    manyTableInfo[TABLENAME.企业基础信息表] = {column:["eId",  "enterpriseName"], where:{} };
    if (enterpriseName) {
        manyTableInfo[TABLENAME.企业基础信息表].where = {enterpriseName:{"%like%":enterpriseName}}
    }
    let resList = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业服务表, selectParam, filesList, manyTableInfo, page );
    let allResList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业服务表, selectParam, ["esId"], manyTableInfo, page );

    
    let dataList = [];
    resList.forEach(info => {
        dataList.push({
            esId:info.esId,
            needCategory:changeEnumValue(enumConfig.NEEDCATEGORY, info.needCategory),
            applyTime:moment(info.applyTime).format("YYYY-MM-DD HH:mm"),
            followUpStatus:changeEnumValue(enumConfig.FOLLOWUPSTATUS, info.followUpStatus),
            resolveTime:info.resolveTime ? moment(info.resolveTime).format("YYYY-MM-DD HH:mm") : '-',
            enterpriseName:info.enterprise.enterpriseName,
            needContent:info.needContent
        });
    });

    return {dataList, dataCount:allResList.length};
}

export async function enterpriseServiceOption(esId:string, fangKui:string) {
    let selectParam:any = {esId};
    let filesList = ["esId"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业服务表, selectParam, filesList);
    if ( !resInfo || !resInfo.esId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业服务表, {fangKui, followUpStatus:enumConfig.FOLLOWUPSTATUS.受理中, shouLiTime:getMySqlMs()}, {esId});

    return {
        isSuccess:true
    };
}

export async function enterpriseServiceEnd(esId:string, outcome:number, desc:string) {
    let selectParam:any = {esId};
    let filesList = ["esId"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业服务表, selectParam, filesList);
    if ( !resInfo || !resInfo.esId) {
        throw new BizError(ERRORENUM.数据不存在);
    }

    let updateInfo = {outcome, followUpStatus:enumConfig.FOLLOWUPSTATUS.已完成, desc, resolveTime:getMySqlMs()};
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业服务表,updateInfo, {esId});

    return {
        isSuccess:true
    };
}


export async function enterpriseRegister(param) {
    const FuncName = "企业注册"
    eccFormParam(FuncName, RegisterUpdateConfig, param );

    let filesList = ["eId", ];
    let enterpriseUserInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {uscc:param.uscc}, filesList);
    if (enterpriseUserInfo && enterpriseUserInfo.eId) {
        throw new BizError(ERRORENUM.企业已存在);
    }
    
    let addEInfo = {
        eId:randomId(TABLEID.企业基础信息表),
        enterpriseName:param.enterpriseName,
        logonAddress:JSON.stringify(["", "", "", param.logonAddress]),
        uscc:param.uscc,
        logonTime:getMySqlMs(param.logonTime),
        state:0,
        register:0
    };
    await operationalData(OPERATIONALDATATYPE.增加, TABLENAME.企业基础信息表, addEInfo, {});

    let fuHuaInfo = {
        eId:addEInfo.eId,
        fId:randomId(TABLEID.企业孵化信息)
    };
    await operationalData(OPERATIONALDATATYPE.增加, TABLENAME.企业孵化信息, fuHuaInfo, {});

    let leaseInfo = {
        eId:addEInfo.eId,
        leaseId:randomId(TABLEID.租赁信息),
        startTime:getMySqlMs(param.leaseTimeStart),
        endTime:getMySqlMs(param.leaseTimeEnd),
        area:param.area
    }
    await operationalData(OPERATIONALDATATYPE.增加, TABLENAME.租赁信息, leaseInfo, {});
   
    return {isSuccess:true};
}


//入孵信息审核
export async function enterpriseRegisterExamineList(entepriseName, page) {
    
    let selectParam:any = {register:enumConfig.STATE.是, state:enumConfig.STATE.否};
    if (entepriseName) selectParam.enterpriseName = {"%like%":entepriseName};

    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "randomCode"];

    let manyTableInfo:any = {}
    manyTableInfo[TABLENAME.租赁信息] = {column:["leaseContract", "entryPlan", "businessLicense", "agreement"], where:{} };
    manyTableInfo[TABLENAME.企业孵化信息] = {column:["state", "startTime", "endTime"], where:{} };
    let resList = await selectManyTableData(OPERATIONALDATATYPE.多表分页, TABLENAME.企业基础信息表, selectParam, filesList, manyTableInfo, page );
    let allResList = await selectManyTableData(OPERATIONALDATATYPE.多表联查, TABLENAME.企业基础信息表, selectParam, ["eId"], manyTableInfo );

    let dataList = [];
    resList.forEach(info => {
        dataList.push({
            eId:info.eId,
            enterpriseName:info.enterpriseName,
            randomCode:info.randomCode,
            leaseContract:info.enterprise_leases[0].leaseContract || "未提交",
            entryPlan:info.enterprise_leases[0].entryPlan || "未提交",
            businessLicense:info.enterprise_leases[0].businessLicense || "未提交",
            agreement:info.enterprise_leases[0].agreement || "未提交"
        });
    });

    return {dataList, dataCount:allResList.length};
}

export async function enterpriseRegisterExaminePass(eId:string) {
    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "state"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);

    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }
    if (resInfo.state) throw new BizError(ERRORENUM.该企业已通过审核);


    
    let updateInfo = {
        state:enumConfig.STATE.是
    }
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业基础信息表, updateInfo, {eId});

    return {isSuccess:true};
}


export async function enterpriseRegisterExamineOut(eId:string) {
    let filesList = ["eId", "enterpriseName", "uscc", "logonTime", "state"];
    let resInfo = await selectData(OPERATIONALDATATYPE.查询单个, TABLENAME.企业基础信息表, {eId}, filesList);

    if (!resInfo || !resInfo.eId) {
        throw new BizError(ERRORENUM.数据不存在);
    }
    if (resInfo.state) throw new BizError(ERRORENUM.该企业已通过审核);

    let updateInfo = {
        register:2
    }
    await operationalData(OPERATIONALDATATYPE.修改, TABLENAME.企业基础信息表, updateInfo, {eId});

    return {isSuccess:true};
}
